@@ -30,6 +30,7 @@
 #include <QMimeData>
 #include <QTimer>
 #include <QFrame>
+#include <QInputDialog>
 
 BookmarksToolbar::BookmarksToolbar(BrowserWindow* window, QWidget* parent)
     : QWidget(parent)
@@ -73,6 +74,7 @@ void BookmarksToolbar::contextMenuRequested(const QPoint &pos)
     QAction* actNewWindow = menu.addAction(IconProvider::newWindowIcon(), tr("Open in new window"));
     QAction* actNewPrivateWindow = menu.addAction(IconProvider::privateBrowsingIcon(), tr("Open in new private window"));
     menu.addSeparator();
+    QAction* actNewFolder = menu.addAction(QIcon::fromTheme("folder-new"), tr("New Folder"));
     QAction* actEdit = menu.addAction(tr("Edit"));
     QAction* actDelete = menu.addAction(QIcon::fromTheme("edit-delete"), tr("Delete"));
     menu.addSeparator();
@@ -88,6 +90,7 @@ void BookmarksToolbar::contextMenuRequested(const QPoint &pos)
     connect(actNewTab, &QAction::triggered, this, &BookmarksToolbar::openBookmarkInNewTab);
     connect(actNewWindow, &QAction::triggered, this, &BookmarksToolbar::openBookmarkInNewWindow);
     connect(actNewPrivateWindow, &QAction::triggered, this, &BookmarksToolbar::openBookmarkInNewPrivateWindow);
+    connect(actNewFolder, &QAction::triggered, this, &BookmarksToolbar::createNewFolder);
     connect(actEdit, &QAction::triggered, this, &BookmarksToolbar::editBookmark);
     connect(actDelete, &QAction::triggered, this, &BookmarksToolbar::deleteBookmark);
 
@@ -115,7 +118,8 @@ void BookmarksToolbar::refresh()
 
     BookmarkItem* folder = mApp->bookmarks()->toolbarFolder();
 
-    foreach (BookmarkItem* child, folder->children()) {
+    const auto children = folder->children();
+    for (BookmarkItem* child : children) {
         addItem(child);
     }
 
@@ -134,7 +138,7 @@ void BookmarksToolbar::showOnlyIconsChanged(bool state)
     }
 
     for (int i = 0; i < m_layout->count(); ++i) {
-        BookmarksToolbarButton* b = qobject_cast<BookmarksToolbarButton*>(m_layout->itemAt(i)->widget());
+        auto* b = qobject_cast<BookmarksToolbarButton*>(m_layout->itemAt(i)->widget());
         if (b) {
             b->setShowOnlyIcon(state);
         }
@@ -148,7 +152,7 @@ void BookmarksToolbar::showOnlyTextChanged(bool state)
     }
 
     for (int i = 0; i < m_layout->count(); ++i) {
-        BookmarksToolbarButton* b = qobject_cast<BookmarksToolbarButton*>(m_layout->itemAt(i)->widget());
+        auto* b = qobject_cast<BookmarksToolbarButton*>(m_layout->itemAt(i)->widget());
         if (b) {
             b->setShowOnlyText(state);
         }
@@ -176,6 +180,25 @@ void BookmarksToolbar::openBookmarkInNewPrivateWindow()
     }
 }
 
+void BookmarksToolbar::createNewFolder() 
+{
+    QString name = QInputDialog::getText(nullptr, tr("New Folder"), tr("Enter Folder Name:"));
+    
+    if (!name.isEmpty()) {
+        BookmarkItem* parent;
+        
+        if (m_clickedBookmark) {
+            parent = m_clickedBookmark;
+        } else {
+            parent = m_bookmarks->toolbarFolder();
+        }
+        
+        auto folder = new BookmarkItem(BookmarkItem::Folder);
+        folder->setTitle(name);
+        m_bookmarks->addBookmark(parent, folder);
+    }
+}
+
 void BookmarksToolbar::editBookmark()
 {
     if (m_clickedBookmark) {
@@ -208,7 +231,7 @@ void BookmarksToolbar::addItem(BookmarkItem* item)
 {
     Q_ASSERT(item);
 
-    BookmarksToolbarButton* button = new BookmarksToolbarButton(item, this);
+    auto* button = new BookmarksToolbarButton(item, this);
     button->setMainWindow(m_window);
     button->setShowOnlyIcon(m_bookmarks->showOnlyIconsInToolbar());
     button->setShowOnlyText(m_bookmarks->showOnlyTextInToolbar());
@@ -243,7 +266,7 @@ void BookmarksToolbar::dropEvent(QDropEvent* e)
     BookmarkItem* bookmark = nullptr;
 
     if (mime->hasFormat(BookmarksButtonMimeData::mimeType())) {
-        const BookmarksButtonMimeData* bookmarkMime = static_cast<const BookmarksButtonMimeData*>(mime);
+        const auto* bookmarkMime = static_cast<const BookmarksButtonMimeData*>(mime);
         bookmark = bookmarkMime->item();
         const int initialIndex = bookmark->parent()->children().indexOf(bookmark);
         BookmarksToolbarButton* current = buttonAt(m_dropPos);
