@@ -47,10 +47,10 @@ ClearPrivateData::ClearPrivateData(QWidget* parent)
 
     ui->setupUi(this);
     ui->buttonBox->setFocus();
-    connect(ui->history, SIGNAL(clicked(bool)), this, SLOT(historyClicked(bool)));
-    connect(ui->clear, SIGNAL(clicked(bool)), this, SLOT(dialogAccepted()));
-    connect(ui->optimizeDb, SIGNAL(clicked(bool)), this, SLOT(optimizeDb()));
-    connect(ui->editCookies, SIGNAL(clicked()), this, SLOT(showCookieManager()));
+    connect(ui->history, &QAbstractButton::clicked, this, &ClearPrivateData::historyClicked);
+    connect(ui->clear, &QAbstractButton::clicked, this, &ClearPrivateData::dialogAccepted);
+    connect(ui->optimizeDb, &QAbstractButton::clicked, this, &ClearPrivateData::optimizeDb);
+    connect(ui->editCookies, &QAbstractButton::clicked, this, &ClearPrivateData::showCookieManager);
 
     Settings settings;
     settings.beginGroup("ClearPrivateData");
@@ -67,22 +67,22 @@ void ClearPrivateData::clearLocalStorage()
 {
     const QString profile = DataPaths::currentProfilePath();
 
-    QzTools::removeRecursively(profile + "/Local Storage");
+    QzTools::removeRecursively(profile + QStringLiteral("/Local Storage"));
 }
 
 void ClearPrivateData::clearWebDatabases()
 {
     const QString profile = DataPaths::currentProfilePath();
 
-    QzTools::removeRecursively(profile + "/IndexedDB");
-    QzTools::removeRecursively(profile + "/databases");
+    QzTools::removeRecursively(profile + QStringLiteral("/IndexedDB"));
+    QzTools::removeRecursively(profile + QStringLiteral("/databases"));
 }
 
 void ClearPrivateData::clearCache()
 {
     const QString profile = DataPaths::currentProfilePath();
 
-    QzTools::removeRecursively(profile + "/GPUCache");
+    QzTools::removeRecursively(profile + QStringLiteral("/GPUCache"));
 
     mApp->webProfile()->clearHttpCache();
 }
@@ -153,7 +153,7 @@ void ClearPrivateData::dialogAccepted()
     ui->clear->setEnabled(false);
     ui->clear->setText(tr("Done"));
 
-    QTimer::singleShot(1000, this, SLOT(close()));
+    QTimer::singleShot(1000, this, &QWidget::close);
 }
 
 void ClearPrivateData::optimizeDb()
@@ -161,11 +161,11 @@ void ClearPrivateData::optimizeDb()
     mApp->setOverrideCursor(Qt::WaitCursor);
 
     const QString profilePath = DataPaths::currentProfilePath();
-    QString sizeBefore = QzTools::fileSizeToString(QFileInfo(profilePath + "/browsedata.db").size());
+    QString sizeBefore = QzTools::fileSizeToString(QFileInfo(profilePath + QStringLiteral("/browsedata.db")).size());
 
     IconProvider::instance()->clearOldIconsInDatabase();
 
-    QString sizeAfter = QzTools::fileSizeToString(QFileInfo(profilePath + "/browsedata.db").size());
+    QString sizeAfter = QzTools::fileSizeToString(QFileInfo(profilePath + QStringLiteral("/browsedata.db")).size());
 
     mApp->restoreOverrideCursor();
 
@@ -174,7 +174,7 @@ void ClearPrivateData::optimizeDb()
 
 void ClearPrivateData::showCookieManager()
 {
-    CookieManager* dialog = new CookieManager(this);
+    auto* dialog = new CookieManager(this);
     dialog->show();
 }
 
