@@ -291,6 +291,7 @@ Preferences::Preferences(BrowserWindow* window)
     ui->intPDFViewer->setChecked(settings.value("intPDFViewer", false).toBool());
     ui->intPDFViewer->setEnabled(ui->allowPlugins->isChecked());
     ui->screenCaptureEnabled->setChecked(settings.value("screenCaptureEnabled", false).toBool());
+    ui->hardwareAccel->setChecked(settings.value("hardwareAccel", false).toBool());
 
     const auto levels = WebView::zoomLevels();
     for (int level : levels) {
@@ -429,15 +430,20 @@ Preferences::Preferences(BrowserWindow* window)
     updateSpellCheckEnabled();
     connect(ui->spellcheckEnabled, &QCheckBox::toggled, this, updateSpellCheckEnabled);
 
-    QStringList dictionariesDirs = {
+    QStringList dictionariesDirs = {};
+    const QByteArray qtWeDictionariesDirs = qgetenv("QTWEBENGINE_DICTIONARIES_PATH");
+    if (!qtWeDictionariesDirs.isNull()) {
+        dictionariesDirs.append(QDir::cleanPath(QString::fromLocal8Bit(qtWeDictionariesDirs)));
+    }
+    else {
 #ifdef Q_OS_OSX
-        QDir::cleanPath(QCoreApplication::applicationDirPath() + QL1S("/../Resources/qtwebengine_dictionaries")),
-        QDir::cleanPath(QCoreApplication::applicationDirPath() + QL1S("/../Frameworks/QtWebEngineCore.framework/Resources/qtwebengine_dictionaries"))
+        dictionariesDirs.append(QDir::cleanPath(QCoreApplication::applicationDirPath() + QL1S("/../Resources/qtwebengine_dictionaries")));
+        dictionariesDirs.append(QDir::cleanPath(QCoreApplication::applicationDirPath() + QL1S("/../Frameworks/QtWebEngineCore.framework/Resources/qtwebengine_dictionaries")));
 #else
-        QDir::cleanPath(QCoreApplication::applicationDirPath() + QL1S("/qtwebengine_dictionaries")),
-        QDir::cleanPath(QLibraryInfo::location(QLibraryInfo::DataPath) + QL1S("/qtwebengine_dictionaries"))
+        dictionariesDirs.append(QDir::cleanPath(QCoreApplication::applicationDirPath() + QL1S("/qtwebengine_dictionaries")));
+        dictionariesDirs.append(QDir::cleanPath(QLibraryInfo::location(QLibraryInfo::DataPath) + QL1S("/qtwebengine_dictionaries")));
 #endif
-    };
+    }
     dictionariesDirs.removeDuplicates();
 
     ui->spellcheckDirectories->setText(dictionariesDirs.join(QL1C('\n')));
@@ -962,7 +968,7 @@ void Preferences::saveSettings()
     settings.setValue("DNSPrefetch", ui->dnsPrefetch->isChecked());
     settings.setValue("intPDFViewer", ui->intPDFViewer->isChecked());
     settings.setValue("screenCaptureEnabled", ui->screenCaptureEnabled->isChecked());
-
+    settings.setValue("hardwareAccel", ui->hardwareAccel->isChecked());
 #ifdef Q_OS_WIN
     settings.setValue("CheckDefaultBrowser", ui->checkDefaultBrowser->isChecked());
 #endif
